@@ -9,14 +9,6 @@ from datetime import datetime
 from .methods import calc_departures, calc_route_departure, recalculate_lead_time
 from typing import Protocol
 
-def tostr(string: Optional[str]) -> str:
-    if not string:
-        return ''
-    else:
-        return string
-
-
-
 def MakeRoute(data: ValidatedTemplate) -> Iterator[Route]:
     data = data.copy()
 
@@ -35,7 +27,7 @@ def MakeRoute(data: ValidatedTemplate) -> Iterator[Route]:
         SDES=data.EDEL,
         DLMC=1,
         DLAC=1,
-        TSID=data.EDEU
+        TSID=data.EDEU.replace('TBD', '')[:4]
     )
 
 
